==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/LinuxPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.LinuxPropertiesArgs.builder
import com.pulumi.azurenative.automation.kotlin.enums.LinuxUpdateClasses
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Linux specific update configuration.
 * @property excludedPackageNameMasks packages excluded from the software update configuration.
 * @property includedPackageClassifications Update classifications included in the software update configuration.
 * @property includedPackageNameMasks packages included from the software update configuration.
 * @property rebootSetting Reboot setting for the software update configuration.
 */
public data class LinuxPropertiesArgs(
    public val excludedPackageNameMasks: Output<List<String>>? = null,
    public val includedPackageClassifications: Output<Either<String, LinuxUpdateClasses>>? = null,
    public val includedPackageNameMasks: Output<List<String>>? = null,
    public val rebootSetting: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.LinuxPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.LinuxPropertiesArgs =
        com.pulumi.azurenative.automation.inputs.LinuxPropertiesArgs.builder()
            .excludedPackageNameMasks(
                excludedPackageNameMasks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .includedPackageClassifications(
                includedPackageClassifications?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .includedPackageNameMasks(
                includedPackageNameMasks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .rebootSetting(rebootSetting?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LinuxPropertiesArgs].
 */
@PulumiTagMarker
public class LinuxPropertiesArgsBuilder internal constructor() {
    private var excludedPackageNameMasks: Output<List<String>>? = null

    private var includedPackageClassifications: Output<Either<String, LinuxUpdateClasses>>? = null

    private var includedPackageNameMasks: Output<List<String>>? = null

    private var rebootSetting: Output<String>? = null

    /**
     * @param value packages excluded from the software update configuration.
     */
    @JvmName("niqucmahkpnuiwru")
    public suspend fun excludedPackageNameMasks(`value`: Output<List<String>>) {
        this.excludedPackageNameMasks = value
    }

    @JvmName("bopeqprtsgjcodrm")
    public suspend fun excludedPackageNameMasks(vararg values: Output<String>) {
        this.excludedPackageNameMasks = Output.all(values.asList())
    }

    /**
     * @param values packages excluded from the software update configuration.
     */
    @JvmName("fwmmmlgqsaioaqly")
    public suspend fun excludedPackageNameMasks(values: List<Output<String>>) {
        this.excludedPackageNameMasks = Output.all(values)
    }

    /**
     * @param value Update classifications included in the software update configuration.
     */
    @JvmName("wrqfrbmnapkaejro")
    public suspend
    fun includedPackageClassifications(`value`: Output<Either<String, LinuxUpdateClasses>>) {
        this.includedPackageClassifications = value
    }

    /**
     * @param value packages included from the software update configuration.
     */
    @JvmName("keeclptnjpjnbglx")
    public suspend fun includedPackageNameMasks(`value`: Output<List<String>>) {
        this.includedPackageNameMasks = value
    }

    @JvmName("hxdesclajdtrbvtq")
    public suspend fun includedPackageNameMasks(vararg values: Output<String>) {
        this.includedPackageNameMasks = Output.all(values.asList())
    }

    /**
     * @param values packages included from the software update configuration.
     */
    @JvmName("pnfahgfaltgkyxul")
    public suspend fun includedPackageNameMasks(values: List<Output<String>>) {
        this.includedPackageNameMasks = Output.all(values)
    }

    /**
     * @param value Reboot setting for the software update configuration.
     */
    @JvmName("wmsvtjyhjxqsxmgp")
    public suspend fun rebootSetting(`value`: Output<String>) {
        this.rebootSetting = value
    }

    /**
     * @param value packages excluded from the software update configuration.
     */
    @JvmName("ppfvfqkklwilxpnk")
    public suspend fun excludedPackageNameMasks(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedPackageNameMasks = mapped
    }

    /**
     * @param values packages excluded from the software update configuration.
     */
    @JvmName("khhijvpoghhwfboa")
    public suspend fun excludedPackageNameMasks(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedPackageNameMasks = mapped
    }

    /**
     * @param value Update classifications included in the software update configuration.
     */
    @JvmName("tkhdyuhqkfcfasxw")
    public suspend fun includedPackageClassifications(`value`: Either<String, LinuxUpdateClasses>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedPackageClassifications = mapped
    }

    /**
     * @param value Update classifications included in the software update configuration.
     */
    @JvmName("awlyjujbeaatffin")
    public fun includedPackageClassifications(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LinuxUpdateClasses>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedPackageClassifications = mapped
    }

    /**
     * @param value Update classifications included in the software update configuration.
     */
    @JvmName("avouvmymnjmbtuiy")
    public fun includedPackageClassifications(`value`: LinuxUpdateClasses) {
        val toBeMapped = Either.ofRight<String, LinuxUpdateClasses>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedPackageClassifications = mapped
    }

    /**
     * @param value packages included from the software update configuration.
     */
    @JvmName("ytygsdmvkprbjemt")
    public suspend fun includedPackageNameMasks(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedPackageNameMasks = mapped
    }

    /**
     * @param values packages included from the software update configuration.
     */
    @JvmName("kxiuxngevfglrold")
    public suspend fun includedPackageNameMasks(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedPackageNameMasks = mapped
    }

    /**
     * @param value Reboot setting for the software update configuration.
     */
    @JvmName("iiubgciwvcahwexg")
    public suspend fun rebootSetting(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rebootSetting = mapped
    }

    internal fun build(): LinuxPropertiesArgs = LinuxPropertiesArgs(
        excludedPackageNameMasks = excludedPackageNameMasks,
        includedPackageClassifications = includedPackageClassifications,
        includedPackageNameMasks = includedPackageNameMasks,
        rebootSetting = rebootSetting,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/LinuxPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.LinuxPropertiesArgs.builder
import com.pulumi.azurenative.automation.kotlin.enums.LinuxUpdateClasses
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Linux specific update configuration.
 * @property excludedPackageNameMasks packages excluded from the software update configuration.
 * @property includedPackageClassifications Update classifications included in the software update configuration.
 * @property includedPackageNameMasks packages included from the software update configuration.
 * @property rebootSetting Reboot setting for the software update configuration.
 */
public data class LinuxPropertiesArgs(
    public val excludedPackageNameMasks: Output<List<String>>? = null,
    public val includedPackageClassifications: Output<Either<String, LinuxUpdateClasses>>? = null,
    public val includedPackageNameMasks: Output<List<String>>? = null,
    public val rebootSetting: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.LinuxPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.LinuxPropertiesArgs =
        com.pulumi.azurenative.automation.inputs.LinuxPropertiesArgs.builder()
            .excludedPackageNameMasks(
                excludedPackageNameMasks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .includedPackageClassifications(
                includedPackageClassifications?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .includedPackageNameMasks(
                includedPackageNameMasks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .rebootSetting(rebootSetting?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LinuxPropertiesArgs].
 */
@PulumiTagMarker
public class LinuxPropertiesArgsBuilder internal constructor() {
    private var excludedPackageNameMasks: Output<List<String>>? = null

    private var includedPackageClassifications: Output<Either<String, LinuxUpdateClasses>>? = null

    private var includedPackageNameMasks: Output<List<String>>? = null

    private var rebootSetting: Output<String>? = null

    /**
     * @param value packages excluded from the software update configuration.
     */
    @JvmName("rdbwdkvvmeqejppd")
    public suspend fun excludedPackageNameMasks(`value`: Output<List<String>>) {
        this.excludedPackageNameMasks = value
    }

    @JvmName("hbptnbodgbpjiifw")
    public suspend fun excludedPackageNameMasks(vararg values: Output<String>) {
        this.excludedPackageNameMasks = Output.all(values.asList())
    }

    /**
     * @param values packages excluded from the software update configuration.
     */
    @JvmName("omfchbxhawlvataj")
    public suspend fun excludedPackageNameMasks(values: List<Output<String>>) {
        this.excludedPackageNameMasks = Output.all(values)
    }

    /**
     * @param value Update classifications included in the software update configuration.
     */
    @JvmName("kkhmwlbfstvhookg")
    public suspend
    fun includedPackageClassifications(`value`: Output<Either<String, LinuxUpdateClasses>>) {
        this.includedPackageClassifications = value
    }

    /**
     * @param value packages included from the software update configuration.
     */
    @JvmName("losqdnhpnestgstk")
    public suspend fun includedPackageNameMasks(`value`: Output<List<String>>) {
        this.includedPackageNameMasks = value
    }

    @JvmName("ecaxaxjhcyjftvmy")
    public suspend fun includedPackageNameMasks(vararg values: Output<String>) {
        this.includedPackageNameMasks = Output.all(values.asList())
    }

    /**
     * @param values packages included from the software update configuration.
     */
    @JvmName("pmupcpsygorfmyaj")
    public suspend fun includedPackageNameMasks(values: List<Output<String>>) {
        this.includedPackageNameMasks = Output.all(values)
    }

    /**
     * @param value Reboot setting for the software update configuration.
     */
    @JvmName("bolgncipabijpiii")
    public suspend fun rebootSetting(`value`: Output<String>) {
        this.rebootSetting = value
    }

    /**
     * @param value packages excluded from the software update configuration.
     */
    @JvmName("snmkuwarrvagxvka")
    public suspend fun excludedPackageNameMasks(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedPackageNameMasks = mapped
    }

    /**
     * @param values packages excluded from the software update configuration.
     */
    @JvmName("xdosutplqwxuvkam")
    public suspend fun excludedPackageNameMasks(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedPackageNameMasks = mapped
    }

    /**
     * @param value Update classifications included in the software update configuration.
     */
    @JvmName("tychoolevoeseqeo")
    public suspend fun includedPackageClassifications(`value`: Either<String, LinuxUpdateClasses>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedPackageClassifications = mapped
    }

    /**
     * @param value Update classifications included in the software update configuration.
     */
    @JvmName("ahkiwavravwthxgc")
    public fun includedPackageClassifications(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LinuxUpdateClasses>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedPackageClassifications = mapped
    }

    /**
     * @param value Update classifications included in the software update configuration.
     */
    @JvmName("nhvmitshvixfxvbt")
    public fun includedPackageClassifications(`value`: LinuxUpdateClasses) {
        val toBeMapped = Either.ofRight<String, LinuxUpdateClasses>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedPackageClassifications = mapped
    }

    /**
     * @param value packages included from the software update configuration.
     */
    @JvmName("xxqwwyphfdpjcrgd")
    public suspend fun includedPackageNameMasks(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedPackageNameMasks = mapped
    }

    /**
     * @param values packages included from the software update configuration.
     */
    @JvmName("bxeoatycyijcmwie")
    public suspend fun includedPackageNameMasks(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedPackageNameMasks = mapped
    }

    /**
     * @param value Reboot setting for the software update configuration.
     */
    @JvmName("fauhjitwvujlnqxi")
    public suspend fun rebootSetting(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rebootSetting = mapped
    }

    internal fun build(): LinuxPropertiesArgs = LinuxPropertiesArgs(
        excludedPackageNameMasks = excludedPackageNameMasks,
        includedPackageClassifications = includedPackageClassifications,
        includedPackageNameMasks = includedPackageNameMasks,
        rebootSetting = rebootSetting,
    )
}
